@@ -14,6 +14,7 @@ sub start {
 		models => $pkg->_build_models($pkg, $path),
 		views => $pkg->_build_views($pkg, $path),
 		controllers => $pkg->_build_controllers($pkg, $path),
+		plugins => $pkg->_build_plugins($pkg, $path),
 		@args
 	);
 	$self->build_app() if ($self->can('build_app'));
@@ -66,6 +67,15 @@ sub _build_controllers {
 	);
 }
 
+sub _build_plugins {
+	my ($self, $pkg, $path) =@_; 
+	return $self->_load_modules(
+		path => $path,
+		pkg => $pkg,
+		type => 'Plugin'
+	);
+}
+
 sub _load_modules {
 	my ($self, %args) = @_;
 	my $type = $args{type};
@@ -154,7 +164,7 @@ Terse::App - Lightweight MVC applications.
 
 =head1 VERSION
 
-Version 0.107
+Version 0.108
 
 =cut
 
