@@ -72,6 +72,13 @@ sub build_terse {
 			return $self->views->{$view};
 		};
 	}
+	if ($self->plugins) {
+		$t->{plugin} = sub {
+			my ($t, $plugin) = @_;
+			$t->raiseError("invalid plugin: ${plugin}", 400) unless $self->plugins->{$plugin};
+			return $self->plugins->{$plugin};
+		};
+	}
 	return $t;
 }
 
@@ -231,7 +238,7 @@ Terse::Controller - controllers made simple.
 
 =head1 VERSION
 
-Version 0.107
+Version 0.108
 
 =cut
 
